System

Struct System 

pub struct System<D> { /* private fields */ }
Represents the entire emulator context.

Implementations

Source

impl<D> System<D>
where D: Debugger + 'static,

pub fn new<T>(cfg: Config, rom: &[u8], hw: T, dbg: D) -> Self
where T: Hardware + 'static,

Create a new emulator context.

pub fn poll(&mut self) -> bool

Run a single step of emulation. This function needs to be called repeatedly until it returns false. Returning false indicates the end of emulation, and the functions shouldn’t be called again.